@@ -21,6 +21,7 @@ var (
 	identifierPat = regexp.MustCompile(`(?i)sid.{0,20}AC[0-9a-f]{32}`) // Should we have this? Seems restrictive.
 	sidPat        = regexp.MustCompile(`\bAC[0-9a-f]{32}\b`)
 	keyPat        = regexp.MustCompile(`\b[0-9a-f]{32}\b`)
+	client        = common.SaneHttpClient()
 )
 
 // Keywords are used for efficiently pre-filtering chunks.
@@ -43,15 +44,15 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	sidMatches := sidPat.FindAllString(dataStr, -1)
 
 	for _, sid := range sidMatches {
-		s := detectors.Result{
-			DetectorType: detectorspb.DetectorType_Twilio,
-			Raw:          []byte(sid),
-			Redacted:     sid,
-		}
+		for _, key := range keyMatches {
+			s1 := detectors.Result{
+				DetectorType: detectorspb.DetectorType_Twilio,
+				Raw:          []byte(sid),
+				RawV2:        []byte(sid + key),
+				Redacted:     sid,
+			}
 
-		if verify {
-			client := common.SaneHttpClient()
-			for _, key := range keyMatches {
+			if verify {
 
 				form := url.Values{}
 				form.Add("FriendlyName", "MyServiceName")
@@ -71,22 +72,22 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 					res.Body.Close() // The request body is unused.
 
 					if res.StatusCode >= 200 && res.StatusCode < 300 {
-						s.Verified = true
+						s1.Verified = true
 					}
 				}
 			}
-		}
 
-		if !s.Verified && detectors.IsKnownFalsePositive(string(s.Raw), detectors.DefaultFalsePositives, true) {
-			continue
-		}
+			if !s1.Verified && detectors.IsKnownFalsePositive(string(s1.Raw), detectors.DefaultFalsePositives, true) {
+				continue
+			}
 
-		if len(keyMatches) > 0 {
-			results = append(results, s)
+			if len(keyMatches) > 0 {
+				results = append(results, s1)
+			}
 		}
 	}
 
-	return
+	return detectors.CleanResults(results), nil
 }
 
 func (s Scanner) Type() detectorspb.DetectorType {
